@@ -3,7 +3,7 @@
 w <- matrix(seq(20,25,length.out=5),ncol=5)*1000
 
 # Run the model
-mod <- dynamAedes(
+mod <- dynamAedes.m(
 	species="koreicus", 
 	scale="ws",
 	intro.eggs=10, 
